<?php
/**
 * Custom and output functions for the theme customizer 
 *
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'posty_mod' ) ) :
/**
 * Wrap get_theme_mod function
 */
function posty_mod( $name ) {

	// Allow our demo plugin to filter
	return apply_filters( 'tj_theme_mod', get_theme_mod( $name, customizer_library_get_default( $name ) ), PREFIX, $name );

}
endif;

if ( ! function_exists( 'posty_textarea_stripslashes' ) ) :
/**
 * Sanitize a textarea for ads.
 *
 * @since  1.0.0
 */
function posty_textarea_stripslashes( $string ) {
	return stripslashes( $string );
}
endif;

/**
 * Custom customizer function.
 *
 * @since  1.0.0
 */
function posty_move_default_customizer( $wp_customize ) {

	// Move the customize to new panel
	$wp_customize->get_section( 'title_tagline' )->panel       = 'header';
	$wp_customize->get_section( 'header_image' )->panel        = 'header';
	$wp_customize->get_section( 'static_front_page' )->panel   = 'general';
	// $wp_customize->get_section( 'colors' )->panel              = 'color';
	$wp_customize->get_section( 'background_image' )->panel    = 'color';

	// Move Color (Background Color)
	$wp_customize->get_control( 'background_color' )->section  = PREFIX . 'site-color-section';

	// moving Theme Layout
	$wp_customize->get_section( 'layout' )->panel              = 'content-layout';
	$wp_customize->get_section( 'layout' )->title              = __( 'Global Layout', 'posty' );
	$wp_customize->get_section( 'layout' )->priority           = 1;

	// Change the title/description
	$wp_customize->get_section( 'title_tagline' )->title       = __( 'Site Title', 'posty' );
	$wp_customize->get_section( 'title_tagline' )->description = __( 'Site title will automatically disapear if you upload a logo.', 'posty' );
	// $wp_customize->get_section( 'colors' )->title              = __( 'Background', 'posty' );
	// $wp_customize->get_section( 'colors' )->priority           = 1;
	$wp_customize->get_section( 'background_image' )->priority = 2;
	$wp_customize->get_section( 'header_image' )->priority     = 1;

	// Live preview
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Remove section
	$wp_customize->remove_section( 'colors' );
	$wp_customize->remove_control( 'header_textcolor' );

}
add_action( 'customize_register', 'posty_move_default_customizer', 20 );

/**
 * Retrieve tags list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function posty_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = __( 'Select a tag &hellip;', 'posty' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Retrieve categories list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function posty_cats_list() {

	// Set up empty array.
	$cats = array();

	// Retrieve available categories.
	$cats_obj = get_categories();

	// Set default/empty tag.
	$cats[''] = __( 'Select a category &hellip;', 'posty' );

	// Display the tags.
	foreach ( $cats_obj as $cat ) {
		$cats[$cat->term_id] = esc_attr( $cat->name );
	}

	return $cats;

}

/**
 * Display theme documentation on customizer page
 */
function posty_documentation_notice() {

	// Enqueue the script
	wp_enqueue_script(
		'posty-customizer-doc',
		get_template_directory_uri() . '/admin/js/doc.js',
		array(), '1.0.0',
		true
	);
 
	// Localize the script
	wp_localize_script(
		'posty-customizer-doc',
		'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/posty' ),
			'prefixLabel' => __( 'Documentation', 'posty' ),
		)
	);
 
}
add_action( 'customize_controls_enqueue_scripts', 'posty_documentation_notice' );