/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	// Theme prefix.
	var prefix = "posty-";

	/**
	 * Live preview site title & site description
	 */
	wp.customize( "blogname", function( value ) {
		value.bind( function( to ) {
			$( ".site-title a" ).text( to );
		} );
	} );

	wp.customize( "blogdescription", function( value ) {
		value.bind( function( to ) {
			$( ".site-description" ).text( to );
		} );
	} );


	/**
	 * Site color
	 */
	wp.customize( prefix + "primary-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#fff';
			$( 'table td, .sf-menu ul, #primary-nav .sf-menu ul, #primary-nav ul.sf-menu li li a, #primary-nav .sf-mega, .widget_newsletter input, .widget_newsletter button, .widget_tabs .tab-content ul li, #footer .widget_newsletter input, .read-more:hover, .more-button, .slicknav_menu, #primary-bar .slicknav_menu .slicknav_icon-bar' ).css('background-color', to);
			$( '.header-social a:link,.header-social a:visited, .header-search a, #primary-nav ul li a, #primary-nav ul li a:hover,#primary-nav ul li.current_item a,#primary-nav ul li.sfHover a, #primary-nav ul li.home_item > a:hover,#primary-nav ul li.current_page_item > a:hover,#primary-nav ul .current-menu-item > a:hover, .widget_tabs #tab4 a:hover, #footer-social a i, .comment-reply-link:link,.comment-reply-link:visited, .comment-reply-link:hover, .read-more:link,.read-more:visited, #featured-content .featured-overlay .entry-header, #featured-content .featured-overlay .entry-header .entry-category a,#featured-content .featured-overlay .entry-header .entry-date,#featured-content .featured-overlay .entry-header .entry-date:before, #featured-content .featured-overlay .entry-title a,#featured-content .featured-overlay .entry-title a:hover, .more-button:hover, .slicknav_nav, #primary-bar .slicknav_menu .slicknav_menutxt, #bbp_search_submit:hover' ).css('color', to);
			$( '.read-more:link,.read-more:visited, .read-more:hover' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "header-bg-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ffffff';
			$( '#masthead' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "light-bg-1-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#ddd';
			$( 'button:hover,#respond #commentform .btn:hover,input[type="submit"]:hover, .comment-reply-link:hover' ).css('background-color', to);
			$( '#respond #commentform input.txt:focus,#respond #commentform textarea:focus' ).css('border-color', to);
			$( '.post-nav .arrow, .widget_tabs .tab-content ul li .entry-meta, .widget_ads .widget-title, .entry-header .entry-date::before, blockquote:before, .entry-author .social-links a, .attachment .entry-meta span span,.attachment .entry-meta span a,.attachment .entry-meta time span,.attachment .entry-meta time a' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "light-bg-2-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#f0f0f0';
			$( 'button,#respond #commentform .btn,input[type="submit"], table th, #primary-bar .slicknav_nav a:hover, table tr:hover td, #searchbar' ).css('background-color', to);
			$( '#searchbar, #primary-nav .sf-menu ul, #primary-nav ul.sf-menu li li a, #primary-nav .sf-mega' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "light-bg-3-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#f5f5f5';
			$( '#primary-nav ul.sf-menu li li a:hover, .widget .widget-title, .widget_tabs .tabs-nav, .widget_tabs #tab4 a, #primary-bar .slicknav_nav, .breadcrumbs, .widget_newsletter .newsletter-widget' ).css('background-color', to);
			$( '.widget_tabs .tab-content ul li' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "border-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#e9e9e9';
			$( 'table, .entry-category a, .more-button, .loop-list .hentry, .loop-blog .hentry,.loop-grid .hentry.first,.loop-list .hentry.first,.layout-1c .loop-blog .hentry,.layout-1c .loop-grid .hentry.first,.layout-1c .loop-list .hentry.first, .pagination a, .layout-1c .loop-grid .hentry,.loop-grid .hentry, input[type="text"],input[type="email"],input[type="url"], textarea, table th, table td, #primary-nav .links li' ).css('border-color', to);
		} );
	} );


	/**
	 * Accent color
	 */
	wp.customize( prefix + "accent-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#3bc492';
			$( '.dark-link a:hover,#footer .widget a:hover,#site-bottom a:hover,.black-link a:hover,.widget a:hover,.comment-name .name a:hover,a:hover,a,.header-social a:hover,.header-search a:hover,#search-submit:hover,#primary-nav ul.sf-menu li li a:hover,#primary-nav ul li.home_item > a,#primary-nav ul li.current_page_item > a,#primary-nav ul .current-menu-item > a,#primary-nav .links li ol li a:hover,#primary-nav .posts .cat-posts .post-list:hover .entry-title,.widget_tabs .tabs-nav li.active a .fa,.widget_tabs .tabs-nav li.active a:visited .fa,.widget_tabs .tabs-nav li a:hover,.widget_tabs .tab-content ul li a:hover .entry-title,.widget_tabs #tab3 li a:hover strong, .widget p a:link' ).css('color', to);
			$( '#primary-nav ul li a:hover,#primary-nav ul li.current_item a,#primary-nav ul li.sfHover a,.widget_tabs #tab4 a:hover,.more-button:hover').css('background-color', to);
			$( '.more-button:hover' ).css('border-color', to);
		} );
	} );

	wp.customize( prefix + "accent-link-hover-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#62d0a8';
			$( 'a:hover,a:visited:hover, .widget p a:hover,.widget p a:visited:hover' ).css('color', to);
			$( 'mark' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "accent-link-visited-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#35b083';
			$( 'a:visited, .widget p a:visited' ).css('color', to);
		} );
	} );


	/**
	 * Text color
	 */
	wp.customize( prefix + "body-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#424242';
			$( 'body' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "heading-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#000';
			console.log(to);
			$( 'ins, mark, button,#respond #commentform .btn,input[type="submit"], button:hover,#respond #commentform .btn:hover,input[type="submit"]:hover, h1,h2,h3,h4,h5,h6, .site-title a, #primary-nav .links li span.column-heading, #primary-nav .posts .cat-posts .post-list .entry-title, .entry-title a:link,.entry-title a:visited, .widget .widget-title, .widget_tabs .tabs-nav li a, #footer-social a:hover, .read-more:hover, .more-button, .post-nav a:hover, .post-nav a:hover > .arrow,.post-nav a:hover > .nav-text span,.post-nav a:hover > .nav-text h5, .pagination a:hover, .black a:hover,.entry-author h5 a:hover' ).css('color', to);
			$( '#primary-bar, #footer-social a:hover > i, #primary-bar .slicknav_menu, #primary-bar .slicknav_nav a:hover' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "secondary-link-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#333';
			$( 'table, .gray-link a:hover,.comment-date a:hover,.entry-footer .entry-comments a:hover,.entry-footer .entry-tags a:hover, .black-link a:link,.widget a:link,.comment-name .name a:link,.black-link a:visited,.widget a:visited,.comment-name .name a:visited, .black a:link,.entry-author h5 a:link,.black a:visited,.entry-author h5 a:visited, .widget_tabs #tab3 li a strong, .entry-header .entry-category a:hover, blockquote cite, .slicknav_menu .slicknav_menutxt, .comment-name' ).css('color', to);
			$( '#bbp_search_submit:hover' ).css('background-color', to);
		} );
	} );

	wp.customize( prefix + "light-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#999';
			$( '.gray-link a:link,.comment-date a:link,.entry-footer .entry-comments a:link,.entry-footer .entry-tags a:link,.gray-link a:visited,.comment-date a:visited,.entry-footer .entry-comments a:visited,.entry-footer .entry-tags a:visited, .ninja-forms-required-items, .wp-caption-text, .site-description, #s, #search-submit, .breadcrumbs span, .entry-meta, .widget_tabs #tab3 li a span, .widget_tabs #tab4 a, .widget_posts_thumbnail .entry-meta, #footer-social a, #respond #commentform .comment-form-desc, .entry-date, .entry-footer, .post-nav span, .post-nav h5, .post-nav a, blockquote, .members .member .member-content .member-position, .attachment .entry-meta span,.attachment .entry-meta time, .slicknav_menu .slicknav_icon, #primary-bar .slicknav_nav a, .widget ul > li' ).css('color', to);
		} );
	} );

	wp.customize( prefix + "footer-text-color", function( value ) {
		value.bind( function( to ) {
			to = to ? to : '#666';
			$( '.dark-link a:link,#footer .widget a:link,#site-bottom a:link,.dark-link a:visited,#footer .widget a:visited,#site-bottom a:visited, #footer .widget, #site-bottom, .entry-author p, #primary-nav ul.sf-menu li li a, .entry-title a:hover, #bbp_search_submit, .gallery-caption' ).css('color', to);
			$( '#footer-social a i' ).css('background-color', to);
		} );
	} );

} )( jQuery );
