<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function posty_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //
	
	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'       => $general_panel,
		'title'    => __( 'General', 'posty' ),
		'priority' => 10
	);

		// RSS
		$section = PREFIX . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'RSS', 'posty' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => __( 'If you fill the custom rss url below, it will replace the default.', 'posty' ),
		);
		$options[PREFIX . 'custom-rss'] = array(
			'id'           => PREFIX . 'custom-rss',
			'label'        => __( 'Custom RSS URL (eg. Feedburner)', 'posty' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = PREFIX . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Comments', 'posty' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'page-comment'] = array(
			'id'           => PREFIX . 'page-comment',
			'label'        => __( 'Page Comment', 'posty' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Social icons
		$section = PREFIX . 'social-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Social', 'posty' ),
			'priority'    => 115,
			'panel'       => $general_panel
		);
		$options[PREFIX . 'social-header'] = array(
			'id'           => PREFIX . 'social-header',
			'label'        => __( 'Show on Header', 'posty' ),
			'description'  => __( 'Show social icons on header', 'posty' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);
		$options[PREFIX . 'social-footer'] = array(
			'id'           => PREFIX . 'social-footer',
			'label'        => __( 'Show on Footer', 'posty' ),
			'description'  => __( 'Show social icons on footer', 'posty' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);
		$options[PREFIX . 'twitter'] = array(
			'id'      => PREFIX . 'twitter',
			'label'   => __( 'Twitter URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'facebook'] = array(
			'id'      => PREFIX . 'facebook',
			'label'   => __( 'Facebook URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'gplus'] = array(
			'id'      => PREFIX . 'gplus',
			'label'   => __( 'Google Plus URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'instagram'] = array(
			'id'      => PREFIX . 'instagram',
			'label'   => __( 'Instagram URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'pinterest'] = array(
			'id'      => PREFIX . 'pinterest',
			'label'   => __( 'Pinterest URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'bloglovin'] = array(
			'id'      => PREFIX . 'bloglovin',
			'label'   => __( 'Bloglovin URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'tumblr'] = array(
			'id'      => PREFIX . 'tumblr',
			'label'   => __( 'Tumblr URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'rss'] = array(
			'id'      => PREFIX . 'rss',
			'label'   => __( 'RSS URL', 'posty' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);

		// Footer Instagram
		$section = PREFIX . 'footer-instagram-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Instagram', 'posty' ),
			'priority'    => 117,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'footer-instagram-title'] = array(
			'id'      => PREFIX . 'footer-instagram-title',
			'label'   => __( 'Instagram Title', 'posty' ),
			'description' => __( 'Enter a title before your Instagram feeds.', 'posty' ),
			'section' => $section,
			'type'    => 'text',
			'default' => __( 'Follow us @Instagram', 'posty' ),
		);
		$options[PREFIX . 'footer-instagram'] = array(
			'id'           => PREFIX . 'footer-instagram',
			'label'        => __( 'Instagram Shortcode', 'posty' ),
			'description'  => sprintf( __( 'Enter your Instagram shortcode. Please install %s first and use <strong>Thumbnails</strong> template only.', 'posty' ), '<a href="https://wordpress.org/plugins/instagram-slider-widget/" target="_blank">Instagram Slider Widget</a>' ),
			'section'      => $section,
			'type'         => 'text',
			'default'      => ''
		);

		// Footer Text
		$section = PREFIX . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Text', 'posty' ),
			'priority'    => 118,
			'panel'       => $general_panel,
		);
		$theme = wp_get_theme();
		$options[PREFIX . 'footer-text'] = array(
			'id'           => PREFIX . 'footer-text',
			'label'        => '',
			'description'  => __( 'Customize the footer text.', 'posty' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => sprintf( __( '&copy; %1$s %2$s &middot; %3$s %4$s &middot; Designed &amp; developed by %5$s', 'posty' ), 
				date( 'Y' ),
				'<a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a>',
				'<span class="themejunkie">',
				'<a href="' . esc_url( $theme->get( 'ThemeURI' ) ) . '">' . esc_attr( $theme->get( 'Name' ) ) . '</a>',
				'<a href="' . esc_url( $theme->get( 'AuthorURI' ) ) . '" rel="designer">' . esc_attr( $theme->get( 'Author' ) ) . '</a>.</span>' )
		);

	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'       => $header_panel,
		'title'    => __( 'Header', 'posty' ),
		'priority' => 15
	);

		$options[PREFIX . 'mobile-icon'] = array(
			'id'           => PREFIX . 'mobile-icon',
			'label'        => __( 'Apple Touch Icon', 'posty' ),
			'section'      => 'title_tagline',
			'priority'     => 99,
			'type'         => 'image',
			'default'      => '',
			'description'  => __( 'File must be <strong>.png</strong> format. Optimal dimensions: <strong>152px x 152px</strong>.', 'posty' ),
		);

		// Logo
		$section = PREFIX . 'logo-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Logo', 'posty' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'logo'] = array(
			'id'      => PREFIX . 'logo',
			'label'   => __( 'Regular Logo', 'posty' ),
			'section' => $section,
			'type'    => 'image',
			'default' => ''
		);
		$options[PREFIX . 'retina-logo'] = array(
			'id'           => PREFIX . 'retina-logo',
			'label'        => __( 'Retina Logo', 'posty' ),
			'description'  => __( 'The Retina Logo should be twice the size of the Regular Logo.', 'posty' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
		);

		// Search icon and form
		$section = PREFIX . 'search-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Search', 'posty' ),
			'description' => __( 'Show search icon and form', 'posty' ),
			'priority'    => 35,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'search-header'] = array(
			'id'      => PREFIX . 'search-header',
			'label'   => '',
			'section' => $section,
			'type'    => 'switch',
			'default' => 1
		);

	// Colors Panel and Sections
	$color_panel = 'color';

	$panels[] = array(
		'id'       => $color_panel,
		'title'    => __( 'Color', 'posty' ),
		'priority' => 20
	);
		
		// Site Color
		$section = PREFIX . 'site-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Site', 'posty' ),
			'priority'    => 5,
			'panel'       => $color_panel
		);
		$options[PREFIX . 'primary-color'] = array(
			'id'          => PREFIX . 'primary-color',
			'label'       => __( 'Primary color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#fff',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'header-bg-color'] = array(
			'id'          => PREFIX . 'header-bg-color',
			'label'       => __( 'Header color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'light-bg-1-color'] = array(
			'id'          => PREFIX . 'light-bg-1-color',
			'label'       => __( 'Light Background color 1', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ddd',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'light-bg-2-color'] = array(
			'id'          => PREFIX . 'light-bg-2-color',
			'label'       => __( 'Light Background color 2', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#f0f0f0',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'light-bg-3-color'] = array(
			'id'          => PREFIX . 'light-bg-3-color',
			'label'       => __( 'Light Background color 3', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#f5f5f5',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'border-color'] = array(
			'id'          => PREFIX . 'border-color',
			'label'       => __( 'Border color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#e9e9e9',
			'transport'   => 'postMessage'
		);

		// Accent Color
		$section = PREFIX . 'accent-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Accent', 'posty' ),
			'priority'    => 15,
			'panel'       => $color_panel
		);
		$options[PREFIX . 'accent-link-color'] = array(
			'id'          => PREFIX . 'accent-link-color',
			'label'       => __( 'Link color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#3bc492',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'accent-link-hover-color'] = array(
			'id'          => PREFIX . 'accent-link-hover-color',
			'label'       => __( 'Link Hover color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#62d0a8',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'accent-link-visited-color'] = array(
			'id'          => PREFIX . 'accent-link-visited-color',
			'label'       => __( 'Link Visited color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#35b083',
			'transport'   => 'postMessage'
		);

		// Text Colors
		$section = PREFIX . 'text-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Text', 'posty' ),
			'priority'    => 20,
			'panel'       => $color_panel
		);
		$options[PREFIX . 'body-color'] = array(
			'id'          => PREFIX . 'body-color',
			'label'       => __( 'Body color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#424242',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'heading-color'] = array(
			'id'          => PREFIX . 'heading-color',
			'label'       => __( 'Heading color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'secondary-link-color'] = array(
			'id'          => PREFIX . 'secondary-link-color',
			'label'       => __( 'Secondary Link color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#333',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'light-text-color'] = array(
			'id'          => PREFIX . 'light-text-color',
			'label'       => __( 'Light Text color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#999',
			'transport'   => 'postMessage'
		);
		$options[PREFIX . 'footer-text-color'] = array(
			'id'          => PREFIX . 'footer-text-color',
			'label'       => __( 'Footer Text color', 'posty' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#666',
			'transport'   => 'postMessage'
		);

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'       => $typo_panel,
		'title'    => __( 'Typography', 'posty' ),
		'priority' => 30
	);

		// Global typography
		$section = PREFIX . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => __( 'Global', 'posty' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[PREFIX . 'text-font'] = array(
			'id'          => PREFIX . 'text-font',
			'label'       => __( 'Text font', 'posty' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Lato',
		);
		$options[PREFIX . 'heading-font'] = array(
			'id'          => PREFIX . 'heading-font',
			'label'       => __( 'Heading font', 'posty' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Playfair Display',
		);

	// Content Panel and Sections
	$content_panel = 'content-layout';

	$panels[] = array(
		'id'       => $content_panel,
		'title'    => __( 'Content Layout', 'posty' ),
		'priority' => 35
	);

		// Featured posts
		$section = PREFIX . 'featured-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Featured Posts', 'posty' ),
			'description' => __( 'Featured posts.', 'posty' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'featured-enable'] = array(
			'id'          => PREFIX . 'featured-enable',
			'label'       => __( 'Show featured posts', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'featured-tag'] = array(
			'id'          => PREFIX . 'featured-tag',
			'label'       => __( 'Select a tag', 'posty' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => posty_tags_list()
		);
		$options[PREFIX . 'featured-num'] = array(
			'id'          => PREFIX . 'featured-num',
			'label'       => __( 'Number of posts', 'posty' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => 6
		);
		$options[PREFIX . 'featured-orderby'] = array(
			'id'          => PREFIX . 'featured-orderby',
			'label'       => __( 'Order by', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'date',
			'choices'     => array(
				'date'  => __( 'Date', 'posty' ),
				'rand'  => __( 'Random', 'posty' )
			)
		);

		// Posts
		$section = PREFIX . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'posty' ),
			'description' => __( 'Posts is a single post page.', 'posty' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'post-meta-group'] = array(
			'id'          => PREFIX . 'post-meta-group',
			'label'       => __( 'Post Meta', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-thumbnail'] = array(
				'id'          => PREFIX . 'post-thumbnail',
				'label'       => __( 'Show featured image', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-date'] = array(
				'id'          => PREFIX . 'post-date',
				'label'       => __( 'Show post date', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-comment'] = array(
				'id'          => PREFIX . 'post-comment',
				'label'       => __( 'Show comment count', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-share'] = array(
				'id'          => PREFIX . 'post-share',
				'label'       => __( 'Show post share', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-author-box'] = array(
				'id'          => PREFIX . 'post-author-box',
				'label'       => __( 'Show post author box', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-nav'] = array(
				'id'          => PREFIX . 'post-nav',
				'label'       => __( 'Show post navigation', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[PREFIX . 'post-date-group'] = array(
			'id'          => PREFIX . 'post-date-group',
			'label'       => __( 'Post Date', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-date-style'] = array(
				'id'          => PREFIX . 'post-date-style',
				'label'       => __( 'Style', 'posty' ),
				'section'     => $section,
				'type'        => 'select',
				'default'     => 'absolute',
				'choices'     => array(
					'absolute' => __( 'Absolute (June 20, 2015 10:19 am)', 'posty' ),
					'relative' => __( 'Relative (1 week ago)', 'posty' )
				)
			);
		$options[PREFIX . 'post-footer-group'] = array(
			'id'          => PREFIX . 'post-footer-group',
			'label'       => __( 'Category and Tag', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-category'] = array(
				'id'          => PREFIX . 'post-category',
				'label'       => __( 'Show post categories', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-tag'] = array(
				'id'          => PREFIX . 'post-tag',
				'label'       => __( 'Show post tags', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[PREFIX . 'related-posts-group'] = array(
			'id'          => PREFIX . 'related-posts-group',
			'label'       => __( 'Related Posts', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'related-posts'] = array(
				'id'          => PREFIX . 'related-posts',
				'label'       => __( 'Show related posts', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'related-posts-img'] = array(
				'id'          => PREFIX . 'related-posts-img',
				'label'       => __( 'Show related posts thumbnail', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'related-posts-date'] = array(
				'id'          => PREFIX . 'related-posts-date',
				'label'       => __( 'Show related posts date', 'posty' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);

		// Page
		$section = PREFIX . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Page', 'posty' ),
			'priority'    => 15,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'page-title'] = array(
			'id'          => PREFIX . 'page-title',
			'label'       => __( 'Show page title', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Archive
		$section = PREFIX . 'archive-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Archive', 'posty' ),
			'description' => __( 'Blog, date, month and year page.', 'posty' ),
			'priority'    => 20,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'archive-layout'] = array(
			'id'          => PREFIX . 'archive-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'grid',
			'choices'     => array(
				'blog'    => __( 'Standard', 'posty' ),
				'list'    => __( 'List', 'posty' ),
				'grid'    => __( 'Grid', 'posty' ),
			)
		);
		$options[PREFIX . 'archive-thumbnail'] = array(
			'id'          => PREFIX . 'archive-thumbnail',
			'label'       => __( 'Show thumbnail', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'archive-category'] = array(
			'id'          => PREFIX . 'archive-category',
			'label'       => __( 'Show category', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'archive-date'] = array(
			'id'          => PREFIX . 'archive-date',
			'label'       => __( 'Show post date', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'archive-excerpt'] = array(
			'id'          => PREFIX . 'archive-excerpt',
			'label'       => __( 'Show excerpt', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'archive-excerpt-limit'] = array(
			'id'          => PREFIX . 'archive-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'posty' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 30
		);
		$options[PREFIX . 'archive-comment'] = array(
			'id'          => PREFIX . 'archive-comment',
			'label'       => __( 'Show comment count', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'archive-share'] = array(
			'id'          => PREFIX . 'archive-share',
			'label'       => __( 'Show social share', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Author page
		$section = PREFIX . 'author-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Author', 'posty' ),
			'description' => __( 'Please navigate the preview to the author page to see the changes.', 'posty' ),
			'priority'    => 25,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'author-layout'] = array(
			'id'          => PREFIX . 'author-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'grid',
			'choices'     => array(
				'blog'    => __( 'Standard', 'posty' ),
				'list'    => __( 'List', 'posty' ),
				'grid'    => __( 'Grid', 'posty' ),
			)
		);
		$options[PREFIX . 'author-thumbnail'] = array(
			'id'          => PREFIX . 'author-thumbnail',
			'label'       => __( 'Show thumbnail', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'author-category'] = array(
			'id'          => PREFIX . 'author-category',
			'label'       => __( 'Show category', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'author-date'] = array(
			'id'          => PREFIX . 'author-date',
			'label'       => __( 'Show post date', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'author-excerpt'] = array(
			'id'          => PREFIX . 'author-excerpt',
			'label'       => __( 'Show excerpt', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'author-excerpt-limit'] = array(
			'id'          => PREFIX . 'author-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'posty' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 30
		);
		$options[PREFIX . 'author-comment'] = array(
			'id'          => PREFIX . 'author-comment',
			'label'       => __( 'Show comment count', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'author-share'] = array(
			'id'          => PREFIX . 'author-share',
			'label'       => __( 'Show social share', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Category
		$section = PREFIX . 'category-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Category', 'posty' ),
			'description' => __( 'Please navigate the preview to the category page to see the changes.', 'posty' ),
			'priority'    => 30,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'cat-layout'] = array(
			'id'          => PREFIX . 'cat-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title',
		);
		$options[PREFIX . 'cat-layout'] = array(
			'id'          => PREFIX . 'cat-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'grid',
			'choices'     => array(
				'blog'    => __( 'Standard', 'posty' ),
				'list'    => __( 'List', 'posty' ),
				'grid'    => __( 'Grid', 'posty' ),
			)
		);
		$options[PREFIX . 'cat-thumbnail'] = array(
			'id'          => PREFIX . 'cat-thumbnail',
			'label'       => __( 'Show thumbnail', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'cat-category'] = array(
			'id'          => PREFIX . 'cat-category',
			'label'       => __( 'Show category', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'cat-date'] = array(
			'id'          => PREFIX . 'cat-date',
			'label'       => __( 'Show post date', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'cat-excerpt'] = array(
			'id'          => PREFIX . 'cat-excerpt',
			'label'       => __( 'Show excerpt', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'cat-excerpt-limit'] = array(
			'id'          => PREFIX . 'cat-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'posty' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 30
		);
		$options[PREFIX . 'cat-comment'] = array(
			'id'          => PREFIX . 'cat-comment',
			'label'       => __( 'Show comment count', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'cat-share'] = array(
			'id'          => PREFIX . 'cat-share',
			'label'       => __( 'Show social share', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Tag page
		$section = PREFIX . 'tag-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Tag', 'posty' ),
			'description' => __( 'Please navigate the preview to the tag page to see the changes.', 'posty' ),
			'priority'    => 35,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'tag-layout'] = array(
			'id'          => PREFIX . 'tag-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'grid',
			'choices'     => array(
				'blog'    => __( 'Standard', 'posty' ),
				'list'    => __( 'List', 'posty' ),
				'grid'    => __( 'Grid', 'posty' ),
			)
		);
		$options[PREFIX . 'tag-category'] = array(
			'id'          => PREFIX . 'tag-category',
			'label'       => __( 'Show category', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'tag-date'] = array(
			'id'          => PREFIX . 'tag-date',
			'label'       => __( 'Show post date', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'tag-thumbnail'] = array(
			'id'          => PREFIX . 'tag-thumbnail',
			'label'       => __( 'Show thumbnail', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'tag-excerpt'] = array(
			'id'          => PREFIX . 'tag-excerpt',
			'label'       => __( 'Show excerpt', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'tag-excerpt-limit'] = array(
			'id'          => PREFIX . 'tag-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'posty' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 30
		);
		$options[PREFIX . 'tag-comment'] = array(
			'id'          => PREFIX . 'tag-comment',
			'label'       => __( 'Show comment count', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'tag-share'] = array(
			'id'          => PREFIX . 'tag-share',
			'label'       => __( 'Show social share', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Search page
		$section = PREFIX . 'search-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Search', 'posty' ),
			'description' => __( 'Please navigate the preview to the search page to see the changes.', 'posty' ),
			'priority'    => 40,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'search-layout'] = array(
			'id'          => PREFIX . 'search-layout',
			'label'       => __( 'Select layout', 'posty' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'grid',
			'choices'     => array(
				'blog'    => __( 'Standard', 'posty' ),
				'list'    => __( 'List', 'posty' ),
				'grid'    => __( 'Grid', 'posty' ),
			)
		);
		$options[PREFIX . 'search-thumbnail'] = array(
			'id'          => PREFIX . 'search-thumbnail',
			'label'       => __( 'Show thumbnail', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'search-category'] = array(
			'id'          => PREFIX . 'search-category',
			'label'       => __( 'Show category', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'search-date'] = array(
			'id'          => PREFIX . 'search-date',
			'label'       => __( 'Show post date', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'search-excerpt'] = array(
			'id'          => PREFIX . 'search-excerpt',
			'label'       => __( 'Show excerpt', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'search-excerpt-limit'] = array(
			'id'          => PREFIX . 'search-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'posty' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 30
		);
		$options[PREFIX . 'search-comment'] = array(
			'id'          => PREFIX . 'search-comment',
			'label'       => __( 'Show comment count', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'search-share'] = array(
			'id'          => PREFIX . 'search-share',
			'label'       => __( 'Show social share', 'posty' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

	// Advertisement Panel and Sections
	$ads_panel = 'advertisement';

	$panels[] = array(
		'id'       => $ads_panel,
		'title'    => __( 'Advertisement', 'posty' ),
		'priority' => 45
	);

		// Header ads
		$section = PREFIX . 'header-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header', 'posty' ),
			'priority'    => 5,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'header-ads-image'] = array(
			'id'           => PREFIX . 'header-ads-image',
			'label'        => __( 'Ads Image', 'posty' ),
			'description'  => __( 'Upload your ads image then put the url in the setting below.', 'posty' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
		);
		$options[PREFIX . 'header-ads-url'] = array(
			'id'           => PREFIX . 'header-ads-url',
			'label'        => __( 'Ads URL', 'posty' ),
			'description'  => __( 'Put the ads url in the box below.', 'posty' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'header-ads-custom'] = array(
			'id'                => PREFIX . 'header-ads-custom',
			'label'             => __( 'Or', 'posty' ),
			'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'posty' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'posty_textarea_stripslashes',
			'default'           => ''
		);

		// Posts ads
		$section = PREFIX . 'posts-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'posty' ),
			'description' => __( 'Single post advertisement', 'posty' ),
			'priority'    => 10,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'post-ads-before'] = array(
			'id'          => PREFIX . 'post-ads-before',
			'label'       => __( 'Ads Before Content', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-ads-image-before'] = array(
				'id'           => PREFIX . 'post-ads-image-before',
				'label'        => __( 'Ads Image', 'posty' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'posty' ),
				'section'      => $section,
				'type'         => 'image',
				'default'      => '',
			);
			$options[PREFIX . 'post-ads-url-before'] = array(
				'id'           => PREFIX . 'post-ads-url-before',
				'label'        => __( 'Ads URL', 'posty' ),
				'description'  => __( 'Put the ads url in the box below.', 'posty' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'post-ads-custom-before'] = array(
				'id'                => PREFIX . 'post-ads-custom-before',
				'label'             => __( 'Or', 'posty' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'posty' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'posty_textarea_stripslashes',
				'default'           => ''
			);
		$options[PREFIX . 'post-ads-after'] = array(
			'id'          => PREFIX . 'post-ads-after',
			'label'       => __( 'Ads After Content', 'posty' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-ads-image-after'] = array(
				'id'           => PREFIX . 'post-ads-image-after',
				'label'        => __( 'Ads Image', 'posty' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'posty' ),
				'section'      => $section,
				'type'         => 'image',
				'default'      => '',
			);
			$options[PREFIX . 'post-ads-url-after'] = array(
				'id'           => PREFIX . 'post-ads-url-after',
				'label'        => __( 'Ads URL', 'posty' ),
				'description'  => __( 'Put the ads url in the box below.', 'posty' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'post-ads-custom-after'] = array(
				'id'                => PREFIX . 'post-ads-custom-after',
				'label'             => __( 'Or', 'posty' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'posty' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'posty_textarea_stripslashes',
				'default'           => ''
			);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'posty_customizer_register' );