<?php
/**
 * Fonts
 *
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'posty_customizer_fonts' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function posty_customizer_fonts() {

	// Text font
	$text  = posty_mod( PREFIX . 'text-font' );
	$stack = customizer_library_get_font_stack( $text );

	if ( $text !== customizer_library_get_default( PREFIX . 'text-font' ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'body',
				'input[type="text"],input[type="email"],input[type="url"]',
				'textarea',
				'button,#respond #commentform .btn,input[type="submit"]',
				'table',
				'.widget .widget-title',
				'.entry-category a',
				'.block-title,#respond .comment-reply-title',
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );
	}

	// Heading font
	$heading = posty_mod( PREFIX . 'heading-font' );
	$stack   = customizer_library_get_font_stack( $heading );

	if ( $heading !== customizer_library_get_default( PREFIX . 'heading-font' ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'h1',
				'h2',
				'h3',
				'h4',
				'h5',
				'h6',
				'.text-wrap.label-above label,.textarea-wrap.label-above label',
				'.field-wrap.label-right label,.field-wrap.label-left label',
				'#primary-nav .links li span.column-heading',
				'.widget_newsletter p',
				'.widget_newsletter input',
				'.widget_tabs #tab3 li a strong',
				'.widget_posts_thumbnail a',
				'#footer #footer-instagram .instagram-heading',
				'#site-bottom',
				'#bbp_search_submit'
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );
	}

}
endif;
add_action( 'posty_customizer_library_styles', 'posty_customizer_fonts' );

if ( ! function_exists( 'posty_enqueue_fonts' ) ) :
/**
 * Enqueue Google Fonts
 *
 * @since  1.0.0
 */
function posty_enqueue_fonts() {

	// Font options
	$fonts = array();

	$heading = posty_mod( PREFIX . 'heading-font' );
	if ( $heading !== customizer_library_get_default( PREFIX . 'heading-font' ) ) {
		$fonts[] = $heading;
		wp_dequeue_style( 'posty-playfair' );
	}
	
	$text  = posty_mod( PREFIX . 'text-font' );
	if ( $text !== customizer_library_get_default( PREFIX . 'text-font' ) ) {
		$fonts[] = $text;
		wp_dequeue_style( 'posty-lato' );
	}

	$font_uri = customizer_library_get_google_font_uri( $fonts );

	// Load Google Fonts
	wp_enqueue_style( 'posty-custom-fonts', $font_uri, array(), null );

}
endif;
add_action( 'wp_enqueue_scripts', 'posty_enqueue_fonts' );