<?php
/**
 * Site color
 *
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'posty_customizer_site_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function posty_customizer_site_styles() {

	// Primary Color
	$primary = posty_mod( PREFIX . 'primary-color' );

	if ( $primary !== customizer_library_get_default( PREFIX . 'primary-color' ) ) {

		$color = sanitize_hex_color( $primary );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'table td',
				'.sf-menu ul',
				'#primary-nav .sf-menu ul',
				'#primary-nav ul.sf-menu li li a',
				'#primary-nav .sf-mega',
				'.widget_newsletter input',
				'.widget_newsletter button',
				'.widget_tabs .tab-content ul li',
				'#footer .widget_newsletter input',
				'.read-more:hover',
				'.more-button',
				'.slicknav_menu',
				'#primary-bar .slicknav_menu .slicknav_icon-bar'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.header-social a:link,.header-social a:visited',
				'.header-search a',
				'#primary-nav ul li a',
				'#primary-nav ul li a:hover,#primary-nav ul li.current_item a,#primary-nav ul li.sfHover a',
				'#primary-nav ul .current_page_item > a:hover,#primary-nav ul .current-menu-item > a:hover',
				'.widget_tabs #tab4 a:hover',
				'#footer-social a i',
				'.comment-reply-link:link,.comment-reply-link:visited',
				'.comment-reply-link:hover',
				'.read-more:link,.read-more:visited',
				'#featured-content .featured-overlay .entry-header',
				'#featured-content .featured-overlay .entry-header .entry-category a,#featured-content .featured-overlay .entry-header .entry-date,#featured-content .featured-overlay .entry-header .entry-date:before',
				'#featured-content .featured-overlay .entry-title a,#featured-content .featured-overlay .entry-title a:hover',
				'.more-button:hover',
				'.slicknav_nav',
				'#primary-bar .slicknav_menu .slicknav_menutxt',
				'#bbp_search_submit:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.read-more:link,.read-more:visited',
				'.read-more:hover'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Header Color
	$header = posty_mod( PREFIX . 'header-bg-color' );

	if ( $header !== customizer_library_get_default( PREFIX . 'header-bg-color' ) ) {

		$color = sanitize_hex_color( $header );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#masthead'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

	// Light Background Color 1
	$light_bg_1 = posty_mod( PREFIX . 'light-bg-1-color' );

	if ( $light_bg_1 !== customizer_library_get_default( PREFIX . 'light-bg-1-color' ) ) {

		$color = sanitize_hex_color( $light_bg_1 );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				// #ddd
				'button:hover,#respond #commentform .btn:hover,input[type="submit"]:hover',
				// #ccc
				'.comment-reply-link:hover'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				// #ddd
				'#respond #commentform input.txt:focus,#respond #commentform textarea:focus'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				// #ddd
				'.post-nav .arrow',
				// #9f9f9f
				'.widget_tabs .tab-content ul li .entry-meta',
				'.widget_ads .widget-title',
				// #ccc
				'.entry-header .entry-date::before',
				'blockquote:before',
				// #cacaca
				'.entry-author .social-links a',
				'.attachment .entry-meta span span,.attachment .entry-meta span a,.attachment .entry-meta time span,.attachment .entry-meta time a'				
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Light Background Color 2
	$light_bg_2 = posty_mod( PREFIX . 'light-bg-2-color' );

	if ( $light_bg_2 !== customizer_library_get_default( PREFIX . 'light-bg-2-color' ) ) {

		$color = sanitize_hex_color( $light_bg_2 );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'button,#respond #commentform .btn,input[type="submit"]',
				'table th',
				'#primary-bar .slicknav_nav a:hover',
				// #f9f9f9
				'table tr:hover td',
				'#searchbar'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#searchbar',
				'#primary-nav .sf-menu ul',
				'#primary-nav ul.sf-menu li li a',
				'#primary-nav .sf-mega'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Light Background Color 3
	$light_bg_3 = posty_mod( PREFIX . 'light-bg-3-color' );

	if ( $light_bg_3 !== customizer_library_get_default( PREFIX . 'light-bg-3-color' ) ) {

		$color = sanitize_hex_color( $light_bg_3 );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#primary-nav ul.sf-menu li li a:hover',
				'.widget .widget-title',
				'.widget_tabs .tabs-nav',
				'.widget_tabs #tab4 a',
				'#primary-bar .slicknav_nav',
				// #f6f6f6 
				'.breadcrumbs',
				'.widget_newsletter .newsletter-widget'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.widget_tabs .tab-content ul li'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Border Color
	$border = posty_mod( PREFIX . 'border-color' );

	if ( $border !== customizer_library_get_default( PREFIX . 'border-color' ) ) {

		$color = sanitize_hex_color( $border );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'table',
				'.entry-category a',
				'.more-button',
				'.loop-list .hentry',
				'.loop-blog .hentry,.loop-grid .hentry.first,.loop-list .hentry.first,.layout-1c .loop-blog .hentry,.layout-1c .loop-grid .hentry.first,.layout-1c .loop-list .hentry.first',
				'.pagination a',
				'.layout-1c .loop-grid .hentry,.loop-grid .hentry',
				// #e6e6e6
				'input[type="text"],input[type="email"],input[type="url"]',
				'textarea',
				'table th',
				'table td',
				'#primary-nav .links li'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

}
endif;
add_action( 'posty_customizer_library_styles', 'posty_customizer_site_styles' );