<?php
/**
 * Content color
 *
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'posty_customizer_content_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function posty_customizer_content_styles() {

	// Body Color
	$body = posty_mod( PREFIX . 'body-color' );

	if ( $body !== customizer_library_get_default( PREFIX . 'body-color' ) ) {

		$color = sanitize_hex_color( $body );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'body'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Heading Color
	$heading = posty_mod( PREFIX . 'heading-color' );

	if ( $heading !== customizer_library_get_default( PREFIX . 'heading-color' ) ) {

		$color = sanitize_hex_color( $heading );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'ins',
				'mark',
				'button,#respond #commentform .btn,input[type="submit"]',
				'button:hover,#respond #commentform .btn:hover,input[type="submit"]:hover',
				'h1,h2,h3,h4,h5,h6',
				'.site-title a',
				'#primary-nav .links li span.column-heading',
				'#primary-nav .posts .cat-posts .post-list .entry-title',
				'.entry-title a:link,.entry-title a:visited',
				'.widget .widget-title',
				'.widget_tabs .tabs-nav li a',
				'#footer-social a:hover',
				'.read-more:hover',
				'.more-button',
				'.post-nav a:hover',
				'.post-nav a:hover > .arrow,.post-nav a:hover > .nav-text span,.post-nav a:hover > .nav-text h5',
				'.pagination a:hover',
				// #141414
				'.black a:hover,.entry-author h5 a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#primary-bar',
				'#footer-social a:hover > i',
				'#primary-bar .slicknav_menu',
				'#primary-bar .slicknav_nav a:hover'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

	// Secondary Link Color
	$secondary_link = posty_mod( PREFIX . 'secondary-link-color' );

	if ( $secondary_link !== customizer_library_get_default( PREFIX . 'secondary-link-color' ) ) {

		$color = sanitize_hex_color( $secondary_link );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'table',
				'.gray-link a:hover,.comment-date a:hover,.entry-footer .entry-comments a:hover,.entry-footer .entry-tags a:hover',
				'.black-link a:link,.widget a:link,.comment-name .name a:link,.black-link a:visited,.widget a:visited,.comment-name .name a:visited',
				'.black a:link,.entry-author h5 a:link,.black a:visited,.entry-author h5 a:visited',
				'.widget_tabs #tab3 li a strong',
				'.entry-header .entry-category a:hover',
				'blockquote cite',
				'.slicknav_menu .slicknav_menutxt',
				// #474747
				'.comment-name'
			),
			'declarations' => array(
				'color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#bbp_search_submit:hover',
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
		
	}

	// Light Text Color
	$light_text = posty_mod( PREFIX . 'light-text-color' );

	if ( $light_text !== customizer_library_get_default( PREFIX . 'light-text-color' ) ) {

		$color = sanitize_hex_color( $light_text );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.gray-link a:link,.comment-date a:link,.entry-footer .entry-comments a:link,.entry-footer .entry-tags a:link,.gray-link a:visited,.comment-date a:visited,.entry-footer .entry-comments a:visited,.entry-footer .entry-tags a:visited',
				'.ninja-forms-required-items',
				'.wp-caption-text',
				'.site-description',
				'#s',
				'#search-submit',
				'.breadcrumbs span',
				'.entry-meta',
				'.widget_tabs #tab3 li a span',
				'.widget_tabs #tab4 a',
				'.widget_posts_thumbnail .entry-meta',
				'#footer-social a',
				'#respond #commentform .comment-form-desc',
				'.entry-date',
				'.entry-footer',
				'.post-nav span',
				'.post-nav h5',
				'.post-nav a',
				'blockquote',
				'.members .member .member-content .member-position',
				'.attachment .entry-meta span,.attachment .entry-meta time',
				'.slicknav_menu .slicknav_icon',
				'#primary-bar .slicknav_nav a',
				'.widget ul > li'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Footer Text Color
	$footer_text = posty_mod( PREFIX . 'footer-text-color' );

	if ( $footer_text !== customizer_library_get_default( PREFIX . 'footer-text-color' ) ) {

		$color = sanitize_hex_color( $footer_text );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.dark-link a:link,#footer .widget a:link,#site-bottom a:link,.dark-link a:visited,#footer .widget a:visited,#site-bottom a:visited',
				'#footer .widget',
				'#site-bottom',
				'.entry-author p',
				// #777
				'#primary-nav ul.sf-menu li li a',
				'.entry-title a:hover',
				'#bbp_search_submit',
				// #707070
				'.gallery-caption'
			),
			'declarations' => array(
				'color' => $color
			)
		) );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#footer-social a i'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}

}
endif;
add_action( 'posty_customizer_library_styles', 'posty_customizer_content_styles' );