<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * 
 * @package    Posty
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'posty_site_branding' ) ) :
/**
 * Site branding for the site.
 * 
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 * 
 * @since  1.0.0
 */
function posty_site_branding() {

	// Get the customizer value.
	$logo   = posty_mod( PREFIX . 'logo' );

	// Check if logo available, then display it.
	if ( $logo ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
			echo '<h2 class="site-description" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'posty_footer_text' ) ) :
/**
 * Footer Text
 */
function posty_footer_text() {

	// Get the customizer data 
	$footer_text = posty_mod( PREFIX . 'footer-text' );

	if ( function_exists( 'pll__' ) )
		$footer_text = pll__( customizer_library_get_default( PREFIX . 'footer-text' ) ); 

	// Display the data
	echo '<div class="copyright">' . stripslashes( $footer_text ) . '</div>';
	
}
endif;

if ( ! function_exists( 'posty_social_icons' ) ) :
/**
 * Header social
 */
function posty_social_icons( $position='header' ) {

	// Get the customizer data 
	$tw        = posty_mod( PREFIX . 'twitter' );
	$fb        = posty_mod( PREFIX . 'facebook' );
	$gplus     = posty_mod( PREFIX . 'gplus' );
	$instagram = posty_mod( PREFIX . 'instagram' );
	$pinterest = posty_mod( PREFIX . 'pinterest' );
	$bloglovin = posty_mod( PREFIX . 'bloglovin' );
	$tumblr    = posty_mod( PREFIX . 'tumblr' );
	$rss       = posty_mod( PREFIX . 'rss' );

	// Display the data
	if ( $tw || $fb || $gplus || $instagram || $pinterest || $bloglovin || $tumblr || $rss ) {

		if ( 'header' == $position ) {
			echo '<div class="header-social">';
		} elseif ( 'footer' == $position ) {
			echo '<div id="footer-social"><div class="container clearfix">';
		}

			if ( $tw ) {
				echo '<a href="' . esc_url( $tw ) . '"><i class="fa fa-twitter"></i> <span>Twitter</span></a> ';
			}
			if ( $fb ) {
				echo '<a href="' . esc_url( $fb ) . '"><i class="fa fa-facebook"></i> <span>Facebook</span></a> ';
			}
			if ( $gplus ) {
				echo '<a href="' . esc_url( $gplus ) . '"><i class="fa fa-google-plus"></i> <span>Google Plus</span></a> ';
			}
			if ( $instagram ) {
				echo '<a href="' . esc_url( $instagram ) . '"><i class="fa fa-instagram"></i> <span>Instagram</span></a> ';
			}
			if ( $pinterest ) {
				echo '<a href="' . esc_url( $pinterest ) . '"><i class="fa fa-pinterest"></i> <span>Pinterest</span></a> ';
			}
			if ( $bloglovin ) {
				echo '<a href="' . esc_url( $bloglovin ) . '"><i class="fa fa-heart"></i> <span>Bloglovin</span></a> ';
			}
			if ( $tumblr ) {
				echo '<a href="' . esc_url( $tumblr ) . '"><i class="fa fa-tumblr"></i> <span>Tumblr</span></a> ';
			}
			if ( $rss ) {
				echo '<a href="' . esc_url( $rss ) . '"><i class="fa fa-rss"></i> <span>RSS</span></a>';
			}

		if ( 'header' == $position ) {
			echo '</div>';
		} elseif ( 'footer' == $position ) {
			echo '</div></div>';
		}

	}
	
}
endif;
if ( ! function_exists( 'posty_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function posty_posted_on( $related=false ) {

	// Get the default layout.
	if ( is_single() ) {
		$date = posty_mod( PREFIX . 'post-date' );
	} elseif ( is_category() ) {
		$date = posty_mod( PREFIX . 'cat-date' );
	} elseif ( is_tag() ) {
		$date = posty_mod( PREFIX . 'tag-date' );
	} elseif ( is_author() ) {
		$date = posty_mod( PREFIX . 'author-date' );
	} elseif ( is_search() ) {
		$date = posty_mod( PREFIX . 'search-date' );
	} else {
		$date = posty_mod( PREFIX . 'archive-date' );
	}

	if ( $related )
		$date = posty_mod( PREFIX . 'related-posts-date' );

	// Get the date style (from Single Posts)
	$date_style = posty_mod( PREFIX . 'post-date-style' );

	if ( $date ) :
	?>
		<span class="entry-date">
			<time class="published" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ) ?>>
				<?php 
				if ( $date_style == 'absolute' ) {
					echo esc_html( get_the_date() );
				} else {
					printf( __( '%s ago', 'posty' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
				}
				?>
			</time>
		</span>
	<?php
	endif;
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function posty_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'posty_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'posty_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so posty_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so posty_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in posty_categorized_blog.
 *
 * @since 1.0.0
 */
function posty_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'posty_categories' );
}
add_action( 'edit_category', 'posty_category_transient_flusher' );
add_action( 'save_post',     'posty_category_transient_flusher' );

if ( ! function_exists( 'posty_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function posty_entry_share() {

	// Get the data set in customizer
	if ( is_single() ) {
		$share = posty_mod( PREFIX . 'post-share' );
	} elseif ( is_category() ) {
		$share = posty_mod( PREFIX . 'cat-share' );
	} elseif ( is_tag() ) {
		$share = posty_mod( PREFIX . 'tag-share' );
	} elseif ( is_author() ) {
		$share = posty_mod( PREFIX . 'author-share' );
	} elseif ( is_search() ) {
		$share = posty_mod( PREFIX . 'search-share' );
	} else {
		$share = posty_mod( PREFIX . 'archive-share' );
	}

	if ( $share == 0 ) {
		return;
	}
	?>
		<span class="entry-share">
			<?php _e( 'Share:', 'posty' ); ?>
			<a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-facebook"></i></a>
			<a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( get_the_ID() ) ); ?>&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-twitter"></i></a>
			<a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i></a>
			<a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;title=<?php echo esc_attr( get_the_title( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i></a>
			<a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i></a>
		</span>
	<?php
}
endif;

if ( ! function_exists( 'posty_post_author_box' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function posty_post_author_box() {

	// Get the data set in customizer
	$enable = posty_mod( PREFIX . 'post-author-box' );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Get the author social information.
	$twitter   = get_the_author_meta( 'twitter' );
	$facebook  = get_the_author_meta( 'facebook' );
	$gplus     = get_the_author_meta( 'gplus' );
	$instagram = get_the_author_meta( 'instagram' );
	$pinterest = get_the_author_meta( 'pinterest' );
?>

	<div class="entry-author" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'posty_author_bio_avatar_size', 100 ), '', strip_tags( get_the_author() ) ); ?>
		<div class="author-content">
			<h5 class="author-title name">
				<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
			</h5>
			<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
			<?php if ( $twitter || $facebook || $gplus || $instagram || $pinterest ) : ?>
				<div class="social-links">
					<?php if ( $twitter ) { ?>
						<a href="//twitter.com/<?php echo esc_attr( $twitter ) ?>"><i class="fa fa-twitter"></i></a>
					<?php } ?>
					<?php if ( $facebook ) { ?>
						<a href="<?php echo esc_url( $facebook ); ?>"><i class="fa fa-facebook"></i></a>
					<?php } ?>
					<?php if ( $gplus ) { ?>
						<a href="<?php echo esc_url( $gplus ); ?>"><i class="fa fa-google-plus"></i></a>
					<?php } ?>
					<?php if ( $instagram ) { ?>
						<a href="<?php echo esc_url( $instagram ); ?>"><i class="fa fa-instagram"></i></a>
					<?php } ?>
					<?php if ( $pinterest ) { ?>
						<a href="<?php echo esc_url( $pinterest ); ?>"><i class="fa fa-pinterest"></i></a>
					<?php } ?>
				</div>
			<?php endif; ?>
		</div><!-- .author-content -->
	</div><!-- .entry-author -->

<?php
}
endif;

if ( ! function_exists( 'posty_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function posty_related_posts() {

	// Get the data set in customizer
	$enable  = posty_mod( PREFIX . 'related-posts' );
	$img     = posty_mod( PREFIX . 'related-posts-img' );
	$date = posty_mod( PREFIX . 'related-posts-date' );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( get_the_ID(), 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}
	
	// Posts query arguments.
	$query = array(
		'post__not_in' => array( get_the_ID() ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 3,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'posty_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div class="entry-related">
			<h3 class="block-title"><span><?php _e( 'You might also like', 'posty' ); ?></span></h3>
			<ul class="clearfix">
				<?php while ( $related->have_posts() ) : $related->the_post(); ?>
					<li>
						<?php if ( has_post_thumbnail() && $img ) : ?>
							<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'post-thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
						<?php endif; ?>
						<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						<?php if ( $date ) : ?>
							<div class="entry-meta">
								<?php posty_posted_on(); ?>
							</div>
						<?php endif; ?>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'posty_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function posty_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<div id="comment-<?php comment_ID(); ?>" class="comment-wrapper">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'posty' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'posty' ), '<span class="edit-link">', '</span>' ); ?></p>
		</div>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<div id="comment-<?php comment_ID(); ?>" class="comment-wrapper">

			<div class="comment-avatar"><figure><?php echo get_avatar( $comment, apply_filters( 'posty_comment_avatar_size', 52 ) ); ?></figure></div>

			<div class="comment-detail">

				<div class="comment-name number">
					<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
					<?php
						printf( '<span class="comment-date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'posty' ), get_comment_date(), get_comment_time() ),
							sprintf( __( '%1$s&middot; Edit%2$s', 'posty' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'posty' ) . '">', '</a>' )
						);
					?>
				</div><!-- .comment-name -->
				
				<div class="comment-description comment" <?php hybrid_attr( 'comment-content' ); ?>>
					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'posty' ); ?></p>
					<?php endif; ?>
					<?php comment_text(); ?>
				</div><!-- .comment-description -->
				
				<span class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'posty' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</span><!-- .reply -->

			</div><!-- .comment-detail -->

		</div><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;


if ( ! function_exists( 'posty_get_first_image' ) ) :
/**
 * Return an HTML img tag for the first image in a post content. Used to draw
 * the content for posts of the “image” format.
 * http://css-tricks.com/snippets/wordpress/get-the-first-image-from-a-post/#comment-1582091 --> not working
 * http://www.wprecipes.com/how-to-get-the-first-image-from-the-post-and-display-it
 *
 * @return string An HTML img tag for the first image in a post content.
 */
function posty_get_first_image( $size='large', $echo=true ) {

	// TO-DO: handle when $echo is false
	if ( has_post_thumbnail() && $echo ) {
		return posty_featured_image( $size );
	}

	// Expose information about the current post.
	global $post;

	// We'll trap to see if this stays empty later in the function.
	$src = '';

	// Grab all img src's in the post content
	// $output = preg_match_all( '//i', $post->post_content, $matches ); // not working
	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);

	// Grab the first img src returned by our regex.
	// if ( ! isset ( $matches[1][0] ) ) { return false; }
	// $src = $matches[1][0];

	// Grab the first <img> complete markup returned by our regex.
	if ( ! isset ( $matches[0][0] ) ) { return false; }
	$src = $matches[0][0];

	// Make sure there's still something worth outputting after sanitization.
	if ( empty( $src ) ) { return false; }

	// add wrapper
	$content = '<div class="entry-image clearfix">';
		$content .= '<a class="img-link" href="' . get_the_permalink() . '">';
			$content .= $src;
		$content .= '</a>';
	$content .= '</div>';

	// choose whether to echo the result or return it as variable
	if ( true == $echo )
		echo $content;
	else
		return $src;

}
endif;

if ( ! function_exists( 'posty_get_format_gallery' ) ) :
/**
 * Get the [gallery] shortcode from the post content and display it on index page. It require
 * gallery ids [gallery ids=1,2,3,4] to display it as thumbnail slideshow. If no ids exist it
 * just display it as standard [gallery] markup.
 *
 * If no [gallery] shortcode found in the post content, get the attached images to the post and 
 * display it as slideshow.
 * 
 * @since  1.0.0
 * @uses   get_post_gallery() to get the gallery in the post content.
 * @uses   wp_get_attachment_image() to get the HTML image.
 * @uses   get_children() to get the attached images if no [gallery] found in the post content.
 * @return string
 */
function posty_get_format_gallery() {

	// set up placeholder
	$slider = '';
	$size = 'large';

	// Check the [gallery] shortcode in post content.
	$gallery = get_post_gallery( get_the_ID(), false );

	// Check if the [gallery] exist.
	if ( $gallery ) {

		// Check if the gallery ids exist.
		if ( isset( $gallery['ids'] ) ) {

			// Get the gallery ids and convert it into array.
			$ids = explode( ',', $gallery['ids'] );

			// Display the gallery in a cool slideshow on index page.
			foreach( $ids as $id ) {
				$slider .= '<li>';
				$slider .= wp_get_attachment_image( $id, $size, false, array( 'class' => 'entry-thumbnail' ) );
				$slider .= '</li>';
			}

		} else {

			// If gallery ids not exist, display the standard gallery markup.
			// avoid this, since it'll look bad
			// $html = get_post_gallery( get_the_ID() );

			// if gallery based on images attached to post (only [gallery] in post content)
			// note: in the post content, better to use: [gallery size="large"] or [gallery size="full"]
			$srcs = $gallery['src'];

			// Display the gallery in a cool slideshow on index page.
			foreach( $srcs as $src ) {
				$slider .= '<li>';
				$slider .= '<img src="' . esc_url( $src ) . '" />';
				$slider .= '</li>';
			}

		}

	// If no [gallery] in post content, get attached images to the post.
	} else {

		// Set up default arguments.
		$defaults = array( 
			'order'          => 'ASC',
			'post_type'      => 'attachment',
			'post_parent'    => get_the_ID(),
			'post_mime_type' => 'image',
			'numberposts'    => -1
		);

		// Retrieves attachments from the post.
		$attachments = get_children( apply_filters( 'posty_gallery_format_args', $defaults ) );

		// Check if attachments exist.
		if ( $attachments ) {

			// Display the attachment images in a cool slideshow on index page.
			foreach ( $attachments as $attachment ) {
				$slider .= '<li>';
				$slider .= wp_get_attachment_image( $attachment->ID, $size, false, array( 'class' => 'entry-thumbnail' ) );
				$slider .= '</li>';
			}

		} else {

			// if no [gallery] shortcode and has no attachments, bail them out
			return;

		}

	}

	// check if gallery is built successfully
	if ( $slider ) :
	?>
	<div class="entry-image clearfix">
		<ul class="bxslider">
			<?php echo $slider; ?>
		</ul>
	</div><!-- .entry-image -->
	<?php endif; 

}
endif;

if ( ! function_exists( 'posty_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did 
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function posty_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( get_the_ID() );
	}

	if ( $url ) {
	?>
		<h2 class="entry-title">
			<a href="<?php echo esc_url( $url ); ?>" itemprop="url">
				<?php if ( get_the_title() && ( __( '(Untitled)', 'posty' ) != get_the_title() ) ) { ?>
					<?php the_title(); ?> &rarr;
				<?php } else { ?>
					<?php echo esc_attr( $url . ' &rarr;' ); ?>
				<?php }	?>
			</a>
		</h2>
	<?php
	}
	
}
endif;

if ( ! function_exists( 'posty_posts_layout' ) ) :
/**
 * Custom archive page layout classes.
 *
 * @since  1.0.0
 */
function posty_posts_layout() {

	// Get the default layout.
	if ( is_category() ) {
		$layout = posty_mod( PREFIX . 'cat-layout' );
	} elseif ( is_tag() ) {
		$layout = posty_mod( PREFIX . 'tag-layout' );
	} elseif ( is_author() ) {
		$layout = posty_mod( PREFIX . 'author-layout' );
	} elseif ( is_search() ) {
		$layout = posty_mod( PREFIX . 'search-layout' );
	} else {
		$layout = posty_mod( PREFIX . 'archive-layout' );
	}

	// Set up empty variable.
	$class = '';

	if ( 'blog' === $layout ) {
		$class = 'loop-blog';
	} elseif ( 'list' === $layout ) {
		$class = 'loop-list';
	} elseif ( 'grid' === $layout ) {
		$class = 'loop-grid';
	} 

	// Allow dev to filter the class.
	echo esc_attr( apply_filters( 'posty_archive_page_classes', $class ) );

}
endif;

if ( ! function_exists( 'posty_entry_category' ) ) :
/**
 * Prints HTML with Category for the current post.
 *
 * @since 1.0.0
 */
function posty_entry_category() {

	// Get the data set in customizer
	if ( is_single() ) {
		$enable = posty_mod( PREFIX . 'post-category' );
	} elseif ( is_category() ) {
		$enable = posty_mod( PREFIX . 'cat-category' );
	} elseif ( is_tag() ) {
		$enable = posty_mod( PREFIX . 'tag-category' );
	} elseif ( is_author() ) {
		$enable = posty_mod( PREFIX . 'author-category' );
	} elseif ( is_search() ) {
		$enable = posty_mod( PREFIX . 'search-category' );
	} else {
		$enable = posty_mod( PREFIX . 'archive-category' );
	}

	$category = get_the_category( get_the_ID() );
	if ( $enable && get_the_category( get_the_ID() ) ) :
	?>
		<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
			<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
		</span><!-- .entry-category -->
	<?php endif; // End if category 

}
endif;

if ( ! function_exists( 'posty_entry_tags' ) ) :
/**
 * Prints HTML with Tags for the current post.
 *
 * @since 1.0.0
 */
function posty_entry_tags() {

	// Hide tags if not in Single Post
	if ( ! is_singular( 'post' ) ) 
		return;

	// Get the data set in customizer
	$tag = posty_mod( PREFIX . 'post-tag' );

	if ( $tag ) :

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'posty' ) );
		if ( $tags_list ) :
		?>
			<span class="entry-tags" <?php hybrid_attr( 'entry-terms', 'post_tag' ); ?>>
				<em>/</em><?php printf( __( 'Tags: %1$s', 'posty' ), $tags_list ); ?>
			</span>
		<?php endif; // End if $tags_list ?>

	<?php endif;
}
endif;

if ( ! function_exists( 'posty_comment_count' ) ) :
/**
 * Comment count
 *
 * @since  1.0.0
 */
function posty_comment_count() {

	// Get the default value.
	if ( is_single() ) {
		$enable = posty_mod( PREFIX . 'post-comment' );
	} elseif ( is_category() ) {
		$enable = posty_mod( PREFIX . 'cat-comment' );
	} elseif ( is_tag() ) {
		$enable = posty_mod( PREFIX . 'tag-comment' );
	} elseif ( is_author() ) {
		$enable = posty_mod( PREFIX . 'author-comment' );
	} elseif ( is_search() ) {
		$enable = posty_mod( PREFIX . 'search-comment' );
	} else {
		$enable = posty_mod( PREFIX . 'archive-comment' );
	}

	if ( $enable ) :
		if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
		<span class="entry-comments"><?php comments_popup_link( __( '0 Comment', 'posty' ), __( '1 Comment', 'posty' ), __( '% Comments', 'posty' ) ); ?></span>
	<?php endif;
	endif; 

}
endif;

if ( ! function_exists( 'posty_featured_image' ) ) :
/**
 * Featured Image
 * 
 * @since  1.0.0
 */
function posty_featured_image( $size='large' ) {

	// Get the data set in customizer
	if ( is_single() ) {
		$enable = posty_mod( PREFIX . 'post-thumbnail' );
	} elseif ( is_category() ) {
		$enable = posty_mod( PREFIX . 'cat-thumbnail' );
	} elseif ( is_tag() ) {
		$enable = posty_mod( PREFIX . 'tag-thumbnail' );
	} elseif ( is_author() ) {
		$enable = posty_mod( PREFIX . 'author-thumbnail' );
	} elseif ( is_search() ) {
		$enable = posty_mod( PREFIX . 'search-thumbnail' );
	} else {
		$enable = posty_mod( PREFIX . 'archive-thumbnail' );
	}

	if ( $enable && has_post_thumbnail() ) :
	?>
		<div class="entry-image clearfix">
			<?php if ( ! is_single() ) : ?>
				<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
			<?php endif; ?>
				<?php the_post_thumbnail( $size ); ?>
			<?php if ( ! is_single() ) : ?>
				</a>
			<?php endif; ?>
		</div>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'posty_entry_header' ) ) :
/**
 * Prints HTML with Category, Post Date and Post Title
 *
 * @since 1.0.0
 */
function posty_entry_header() {
?>
	<header class="entry-header">
		<?php if ( 'post' == get_post_type() ) : ?>
			<div class="entry-meta">
				<?php posty_entry_category(); ?>
				<?php posty_posted_on(); ?>
			</div><!-- .entry-meta -->
		<?php endif; ?>

		<?php
		if ( is_single() ) {
			the_title( '<h1 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h1>' );
		} else {

			// Get the data set in customizer
			if ( is_category() ) {
				$layout = posty_mod( PREFIX . 'cat-layout' );
			} elseif ( is_tag() ) {
				$layout = posty_mod( PREFIX . 'tag-layout' );
			} elseif ( is_author() ) {
				$layout = posty_mod( PREFIX . 'author-layout' );
			} elseif ( is_search() ) {
				$layout = posty_mod( PREFIX . 'search-layout' );
			} else {
				$layout = posty_mod( PREFIX . 'archive-layout' );
			}

			if ( ( 'blog' == $layout ) && has_post_format( 'link' ) ) :
				posty_get_post_format_link_url();
			else :
				the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' );
			endif;

		}
		?>
	</header><!-- .entry-header -->
	<?php
}
endif;

if ( ! function_exists( 'posty_entry_footer' ) ) :
/**
 * Prints HTML with Comments, Social share, Edit link in the footer
 *
 * @since 1.0.0
 */
function posty_entry_footer() {
?>
	<footer class="entry-footer clearfix">
		<?php posty_comment_count(); ?>		

		<?php if ( is_single() ) posty_entry_tags(); ?>
		
		<?php edit_post_link( __( 'Edit', 'posty' ), '<span class="sep">/</span><span class="edit-link">', '</span>' ); ?>

		<?php posty_entry_share(); ?>
	</footer><!-- .entry-footer -->
	<?php
}
endif;

if ( ! function_exists( 'posty_attachment_meta' ) ) :
/**
 * Prints HTML with meta information for image attachment
 *
 * @since 1.0.0
 */
function posty_attachment_meta() {
	?>

	<time class="entry-date published entry-side" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php printf( __( 'Published: %s', 'posty' ), '<span>' . esc_html( get_the_date() ) . '</span>' ); ?></time>
	
	<span class="author vcard entry-side" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php printf( __( 'Author: %s', 'posty' ), '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a>' ); ?>
	</span>

	<?php if ( is_attachment() && wp_attachment_is_image() ) : ?>

		<?php 
		$metadata = wp_get_attachment_metadata(); // Retrieve attachment metadata.
		$camera   = $metadata['image_meta']['camera'];
		$aperture = $metadata['image_meta']['aperture'];
		$focal    = $metadata['image_meta']['focal_length'];
		$iso      = $metadata['image_meta']['iso'];
		$shutter  = $metadata['image_meta']['shutter_speed'];
		?>
		
		<span class="full-size-link entry-side">
			<?php printf( __( 'Size: %s', 'posty' ), '<a href="' . esc_url( wp_get_attachment_url() ) . '">' . $metadata['width'] . ' &times; ' . $metadata['height'] . '</a>' ); ?>
		</span>
		
		<?php if ( $camera ) : ?>
			<span class="camera entry-side">
				<?php printf( __( 'Camera: %s', 'posty' ), '<span>' . $camera . '</span>' ); ?>
			</span>
		<?php endif; ?>
		
		<?php if ( $aperture ) : ?>
			<span class="apparture entry-side">
				<?php printf( __( 'Aperture: %s', 'posty' ), '<span>' . $aperture . '</span>' ); ?>
			</span>
		<?php endif; ?>
		
		<?php if ( $focal ) : ?>
			<span class="focal-length entry-side">
				<?php printf( __( 'Focal Length: %s', 'posty' ), '<span>' . $focal . '</span>' ); ?>
			</span>
		<?php endif; ?>
		
		<?php if ( $iso ) : ?>
			<span class="iso entry-side">
				<?php printf( __( 'ISO: %s', 'posty' ), '<span>' . $iso . '</span>' ); ?>
			</span>
		<?php endif; ?>
		
		<?php if ( $shutter ) : ?>
			<span class="shutter-speed entry-side">
				<?php printf( __( 'Shutter Speed: %s', 'posty' ), '<span>' . $shutter . '</span>' ); ?>
			</span>
		<?php endif; ?>
	
	<?php endif; ?>

	<?php
}
endif;

if ( ! function_exists( 'posty_featured_slider' ) ) :
/**
 * Content Slider
 */
function posty_featured_slider() {

	// Display on home page only
	if ( ! is_home() ) {
		return;
	}

	// Get the data set in customizer
	$enable  = posty_mod( PREFIX . 'featured-enable' );
	$tag     = posty_mod( PREFIX . 'featured-tag' );
	$num     = posty_mod( PREFIX . 'featured-num' );
	$orderby = posty_mod( PREFIX . 'featured-orderby' );

	// Check if it enabled.
	if ( ! $enable )
		return;

	// Posts query arguments.
	$args = array(
		'post_type'           => 'post',
		'posts_per_page'      => absint( $num ),
		'orderby'             => $orderby,
		'ignore_sticky_posts' => 1
	);

	// Limit to tag based on user selected tag.
	if ( ! empty( $tag ) ) {
		$args['tag_id'] = $tag;
	}

	// Allow dev to filter the post arguments.
	$args = apply_filters( 'posty_featured_slider_args', $args );

	// The post query.
	$slider = new WP_Query( $args );

	if ( $slider->have_posts() ) :
?>
		<div id="featured-content" class="container">
			<div class="entry-image bxslider-wrap">
				<ul class="bxslider">

					<?php while ( $slider->have_posts() ) : $slider->the_post(); ?>
						
						<li>
							<?php if ( has_post_thumbnail() ) : ?>
								<?php 
								global $content_width; 
								$temp_width = $content_width;
								$content_width = 1080; // tweak for fullwidth 
								?>
								<?php the_post_thumbnail( 'large', array( 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php $content_width = $temp_width; // set back to inital ?>
							<?php else : ?>
								<img class="entry-thumbnail" width="1080" height="680" src="<?php echo esc_url( '//placehold.it/1080x680/?text=' . urlencode( get_the_title() ) ); ?>" alt="<?php the_title_attribute(); ?>" />
							<?php endif; ?>
							<div class="featured-overlay">
								<div class="entry-header">
									<div class="entry-meta">
										<?php posty_entry_category(); ?>
										<?php posty_posted_on(); ?>
									</div>							
									<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" itemprop="url" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
									<a href="<?php the_permalink(); ?>" class="read-more"><?php _e( 'Read More', 'posty' ); ?></a>
								</div>
							</div>
						</li>

					<?php endwhile; ?>

				</ul><!-- .slides -->
			</div><!-- .entry-image -->
		</div><!-- #featured-content -->
	<?php
	endif;

	wp_reset_postdata();
}
endif;

if ( ! function_exists( 'posty_breadcrumbs') ) :
/**
 * 
 */
function posty_breadcrumbs() {

	if ( is_category() ) {
		$subtitle = __( 'Browse Category', 'posty' );
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$subtitle = __( 'Browse Tag', 'posty' );
		$title = single_tag_title( '', false );
	} elseif ( is_tax() ) {
		$subtitle = __( 'Browse Archive', 'posty' );
		$title = single_term_title( '', false );
	} elseif ( is_author() ) {
		$subtitle = __( 'Browse Author', 'posty' );
		$title = get_the_author_meta( 'display_name', get_query_var( 'author' ) );
	} elseif ( is_search() ) {
		$subtitle = __( 'Search Results for', 'posty' );
		$title = esc_attr( get_search_query() );
	} else {
		// if not on those pages, bail out
		return;
	}
?>
<div class="breadcrumbs">
	<span><?php echo $subtitle; ?></span>
	<h1><?php echo $title; ?></h1>
</div>
<?php
}
endif;